function y=solve_second_order_mm(h_1,B,C,epsilon_2,a_c,m,l,xi,psi)
% harmonic solver at second order
k=1; % nondim wave number
N=20; % number of time modes

h(1:N-1,1)=flipud(conj(h_1(2:N,1)));
h(N:2*N-1,1)=h_1;

A=zeros(2*N,2*N);
rhs=zeros(2*N,1);
for n_i=1:2:2*l-1 % because you have a zero mode
    n_count=(n_i-1)/2;
    E_A=((-(n_count)^2+4*epsilon_2*1i*(2*k)^2*(n_count))...
        +2*k*(B+C*(2*k)^2));
    % real
    A(n_i,2*abs(n_count-l)+1)=B*k*a_c*sin(xi)*cos(psi);
    A(n_i,2*abs(n_count-l)+2)=B*k*a_c*sin(xi)*sin(psi); % flip sign of imag part
    if n_count-m<0
        A(n_i,2*abs(n_count-m)+1)=B*k*a_c*cos(xi);
    else
        A(n_i,n_i-2*m)=B*k*a_c*cos(xi);
    end
    A(n_i,n_i)=real(E_A); 
    A(n_i,n_i+1)=-imag(E_A);%C
    A(n_i,n_i+2*m)=B*k*a_c*cos(xi);
    A(n_i,n_i+2*l)=B*k*a_c*sin(xi)*cos(psi);
    A(n_i,n_i+2*l+1)=B*k*a_c*sin(xi)*sin(psi);
    
    % imag
    A(n_i+1,2*abs(n_count-l)+1)=B*k*a_c*sin(xi)*sin(psi);
    A(n_i+1,2*abs(n_count-l)+2)=-B*k*a_c*sin(xi)*cos(psi);
    if n_count-m<0
        A(n_i+1,2*abs(n_count-m)+2)=-B*k*a_c*cos(xi);
    else
        A(n_i+1,n_i-2*m+1)=B*k*a_c*cos(xi);
    end
    A(n_i+1,n_i)=imag(E_A); 
    A(n_i+1,n_i+1)=real(E_A);%C
    A(n_i+1,n_i+2*m)=B*k*a_c*cos(xi);
    A(n_i+1,n_i+2*l)=-B*k*a_c*sin(xi)*sin(psi);
    A(n_i+1,n_i+2*l+1)=B*k*a_c*sin(xi)*cos(psi);
    
    % rhs
    rhs_temp=0+0*1i;
    for r=1:length(h) % index of h
        r_wn=r-N; % corresponding wavenumber
        s_wn=n_count-r_wn; %'paired' wavenumber
        s=s_wn+N; % corresponding index
        if s<40 && r<40
        rhs_temp=rhs_temp+h(r,1)*h(s,1);
        end
    end
    rhs(n_i,1)=2*k^3*real(rhs_temp);
    rhs(n_i+1,1)=2*k^3*imag(rhs_temp);
end
for n_i=2*l+1:2:2*(N-l)-1 % because you have a zero mode
    n_count=(n_i-1)/2;
    E_A=((-(n_count)^2+4*epsilon_2*1i*(2*k)^2*(n_count))...
        +2*k*(B+C*(2*k)^2));
    % real
    A(n_i,n_i-2*l)=B*k*a_c*sin(xi)*cos(psi);
    A(n_i,n_i-2*l+1)=-B*k*a_c*sin(xi)*sin(psi);
    A(n_i,n_i-2*m)=B*k*a_c*cos(xi);
    A(n_i,n_i)=real(E_A); 
    A(n_i,n_i+1)=-imag(E_A);%C
    A(n_i,n_i+2*m)=B*k*a_c*cos(xi);
    A(n_i,n_i+2*l)=B*k*a_c*sin(xi)*cos(psi);
    A(n_i,n_i+2*l+1)=B*k*a_c*sin(xi)*sin(psi);
    
    % imag
    A(n_i+1,n_i-2*l)=B*k*a_c*sin(xi)*sin(psi);
    A(n_i+1,n_i-2*l+1)=B*k*a_c*sin(xi)*cos(psi);
    A(n_i+1,n_i-2*m+1)=B*k*a_c*cos(xi);
    A(n_i+1,n_i)=imag(E_A); 
    A(n_i+1,n_i+1)=real(E_A);%C
    A(n_i+1,n_i+2*m)=B*k*a_c*cos(xi);
    A(n_i+1,n_i+2*l)=-B*k*a_c*sin(xi)*sin(psi);
    A(n_i+1,n_i+2*l+1)=B*k*a_c*sin(xi)*cos(psi);
    
    % rhs
    rhs_temp=0+0*1i;
    for r=1:length(h) % index of h
        r_wn=r-N; % corresponding wavenumber
        s_wn=n_count-r_wn; %'paired' wavenumber
        s=s_wn+N; % corresponding index
        if s<40 && r<40
        rhs_temp=rhs_temp+h(r)*h(s);
        end
    end
    rhs(n_i,1)=2*k^3*real(rhs_temp);
    rhs(n_i+1,1)=2*k^3*imag(rhs_temp);
end
for n_i=2*(N-l)+1:2:2*N-1 % because you have a zero mode
    n_count=(n_i-1)/2;
    E_A=((-(n_count)^2+4*epsilon_2*1i*(2*k)^2*(n_count))...
        +2*k*(B+C*(2*k)^2));
    % real
    A(n_i,n_i-2*l)=B*k*a_c*sin(xi)*cos(psi);
    A(n_i,n_i-2*l+1)=-B*k*a_c*sin(xi)*sin(psi);
    A(n_i,n_i-2*m)=B*k*a_c*cos(xi);
    A(n_i,n_i)=real(E_A); 
    A(n_i,n_i+1)=-imag(E_A);%C
    if n_count+m<N-1
    A(n_i,n_i+2*m)=B*k*a_c*cos(xi);
    end
    
    % imag
    A(n_i+1,n_i-2*l)=B*k*a_c*sin(xi)*sin(psi);
    A(n_i+1,n_i-2*l+1)=B*k*a_c*sin(xi)*cos(psi);
    A(n_i+1,n_i-2*m+1)=B*k*a_c*cos(xi);
    A(n_i+1,n_i)=imag(E_A); 
    A(n_i+1,n_i+1)=real(E_A);%C
    if n_count+m<N-1
    A(n_i+1,n_i+2*m)=B*k*a_c*cos(xi);
    end
    
    % rhs
    rhs_temp=0+0*1i;
    for r=1:length(h) % index of h
        r_wn=r-N; % corresponding wavenumber
        s_wn=n_count-r_wn; %'paired' wavenumber
        s=s_wn+N; % corresponding index
        if s<40 && r<40
        rhs_temp=rhs_temp+h(r)*h(s);
        end
    end
    rhs(n_i,1)=2*k^3*real(rhs_temp);
    rhs(n_i+1,1)=2*k^3*imag(rhs_temp);
end

y=A\rhs;