clc
clear all
close all

% all nondimensional
addpath('./FINAL_functions_2d_hex/')
addpath('./functions_amp_eqn_3freq/')
% configuration
% set up parameters of the system
epsilon_2=1;
C=1;
B=4;
psil=4.5*pi/4;
psip=0;

ang=0.81*pi/2;

m=2;
m_forcing=cos(ang);
l=3;
l_forcing=sin(ang);
p=4;
p_forcing=0;

% time nodes to calculate stability
N_t=40;
k_start=0.01;
k_end=2;
k_step=1000;
dk=(k_end-k_start)/k_step;

visc_option=1; % include all visc in linear approximations? (1 for yes, 0 for no)

% find first critical value of a for SH (1,:) and H (2,:) tongues
a_and_k_crit=bisect_for_min_a_and_k_3freq(B,C,epsilon_2,psil,psip,...
    m_forcing,l_forcing,p_forcing,m,l,p,k_start,k_end,dk,N_t,visc_option);
[a_c,a_pos]=min(a_and_k_crit(:,1));
k_0=a_and_k_crit(a_pos,2);

% forcing amplitude
a_0=1;%(4*epsilon_2/B);
% distance from critical forcing as a multiple of (4*epsilon_2/B)
EPS=0.001;
% nondim forcing
a_forcing=(1+EPS)*a_and_k_crit(a_pos,1); % already nondim

% number of space modes
N_x=2^5;
N_y=2^5;

% time steps per period
time_steps_per_period=200;
% how many multpiles of the period of forcing to go
time_step_multiple=2000; % set to 1 to represent nonstop

% set up nondim spatial domain
if a_pos>1.5 % harmonic hexagons

x_st=0;
x_l=2*2*pi/k_0; % corresponds to n=1 mode
x_en=x_st+x_l;
% set up nondim spatial domain
y_st=0;
y_l=2*2*pi/sqrt(3)/k_0; % corresponds to n=1 mode
y_en=y_st+y_l;
% sample points in nondim space
x_i=linspace(x_st,x_en-x_l/N_x,N_x);
y_i=linspace(y_st,y_en-y_l/N_y,N_y)';

h_0=0.1*(cos(4*pi*x_i/x_l)+cos(2*pi*x_i/x_l+2*pi*y_i/y_l)+cos(2*pi*x_i/x_l-2*pi*y_i/y_l));
phi_0=0.1*(cos(4*pi*x_i/x_l)+cos(2*pi*x_i/x_l+2*pi*y_i/y_l)+cos(2*pi*x_i/x_l-2*pi*y_i/y_l));
%h_0=0.1*rand(N_y,N_x);
%phi_0=0.1*rand(N_y,N_x);

else % squares

x_st=0;
x_l=2*pi/k_0; % corresponds to n=1 mode
x_en=x_st+x_l;
% set up nondim spatial domain
y_st=0;
y_l=2*pi/k_0; % corresponds to n=1 mode
y_en=y_st+y_l;
% sample points in nondim space
x_i=linspace(x_st,x_en-x_l/N_x,N_x);
y_i=linspace(y_st,y_en-y_l/N_y,N_y)';

% initial conditions % currently set to sin % writen to file
h_0=0.1*(cos(x_i)+cos(y_i)); % make sure not too big
phi_0=0.1*(cos(x_i)+cos(y_i)); % make sure not too big

end

% determine time step
total_time_steps=time_step_multiple*time_steps_per_period; % total amount of steps
% to keep DT the same over whole time
% total time values
time_start=0; % for starting fresh
% time_start=readmatrix('time_end.txt'); % for continuing solution
time_end=time_start+time_step_multiple*2*pi; % end time

% set up periodic forcing vector for one period nondim
t_i=linspace(0,2*pi-2*pi/time_steps_per_period,time_steps_per_period);
prop_m=1; prop_l=1;
sin_2_t=prop_m*m_forcing*cos(m*t_i)+prop_l*l_forcing*cos(l*t_i+psil);

% take a sample every sample_point steps
sample_point=time_steps_per_period;

% % write path for configuration
file_path=strcat('final_result_hex_',num2str(epsilon_2),'_',num2str(B),'_',...
    num2str(C),'_',num2str(N_y),'_',num2str(N_x),'_',num2str(EPS,'%1.7f'),'_',...
    num2str(ang,'%1.4f'),'_',num2str(psil,'%1.4f'),...
	'_',num2str(time_steps_per_period));
file_path=replace(file_path,'.','p');
file_path=replace(file_path,'-','minus');
file_path=strcat('/nobackup/scrco/',file_path);
if not(isfolder(file_path))
     mkdir(strcat(file_path))
end

% to continue solution
% clear h_0 phi_0
% h_0(:,:,1)=1*readmatrix(strcat(file_path,'/CONT_h_min1.txt'));
% phi_0(:,:,1)=1*readmatrix(strcat(file_path,'/CONT_phi_min1.txt'));
% h_0(:,:,2)=1*readmatrix(strcat(file_path,'/CONT_h.txt'));
% phi_0(:,:,2)=1*readmatrix(strcat(file_path,'/CONT_phi.txt'));

% read initial condition from other solution
% clear h_0 phi_0
% h_0(:,:,1)=1*readmatrix(strcat('/CONT_h_min1.txt'));
% phi_0(:,:,1)=1*readmatrix(strcat('/CONT_phi_min1.txt'));
% h_0(:,:,2)=1*readmatrix(strcat('/CONT_h.txt'));
% phi_0(:,:,2)=1*readmatrix(strcat('/CONT_phi.txt'));

% write configuration in full
str=["B",num2str(B);...
"C",num2str(C);...
"m",num2str(m);...
"m_forcing",num2str(m_forcing);...
"l",num2str(l);...
"l_forcing",num2str(l_forcing);...
"p",num2str(p);...
"p_forcing",num2str(p_forcing);...
"psil",num2str(psil);...
"psip",num2str(psip);...
"N_t",num2str(N_t);...
"k_start",num2str(k_start);...
"k_end",num2str(k_end);...
"visc_option (1 yes, 0 no)",num2str(visc_option);...
"a_crit",num2str(a_c);...
"a_forcing",num2str(a_forcing);...
"EPS",num2str(EPS);...
"a_pos (1 subharmonic, 2 harmonic)",num2str(a_pos);...
"k_0",num2str(k_0);...
"epsilon_2",num2str(epsilon_2);...
"domain_size",strcat(num2str(N_x)," by ",num2str(N_y))];
writematrix(str,strcat(file_path,'/configuration.txt'))

% for first run
[sol_h,sol_phi,T,L2]=step_in_ETD2_2d_arc(time_start,time_end,...
   time_steps_per_period,total_time_steps,x_l,y_l,N_x,N_y,h_0,phi_0...
   ,a_forcing,epsilon_2,B,C,sin_2_t,sample_point,x_i,y_i,file_path);

% for continuing
% [sol_h,sol_phi,T,L2]=step_in_ETD2_continued_2d_arc(time_start,time_end,...
%   time_steps_per_period,total_time_steps,x_l,y_l,N_x,N_y...
%    ,a_forcing,epsilon_2,B,C,sin_2_t,sample_point,x_i,y_i,h_0(:,:,1)...
%    ,h_0(:,:,2),phi_0(:,:,1),phi_0(:,:,2),file_path);

config_vec=[epsilon_2,C,B,psil,psip,ang,m,m_forcing,l,l_forcing,...
    p,p_forcing,a_c,k_0,EPS,time_steps_per_period,N_x,N_y,a_pos]';
writematrix(config_vec,strcat(file_path,'/config_vec.txt'));
fid=fopen('config_path.txt','wt');
fprintf(fid,file_path);
fclose(fid);

quit;


