% for local only
clc
clear all
close all

% all nondimensional
addpath('./FINAL_functions_2d_local/')
addpath('./functions_amp_eqn_3freq/')
% configuration
load('./config_vec.txt');

% set up parameters of the system
epsilon_2=config_vec(1);
C=config_vec(2);
B=config_vec(3);
psil=config_vec(4);
psip=config_vec(5);

ang=config_vec(6);

m=config_vec(7);
m_forcing=cos(ang);
l=config_vec(9);
l_forcing=sin(ang);
p=config_vec(11);
p_forcing=0;

visc_option=1; % include all visc in linear approximations? (1 for yes, 0 for no)

% find first critical value of a for SH (1,:) and H (2,:) tongues
a_c=config_vec(13)
k_0=config_vec(14);

% forcing amplitude
a_0=1;%(4*epsilon_2/B);
% distance from critical forcing as a multiple of (4*epsilon_2/B)
EPS=config_vec(15);
% nondim forcing
a_forcing=(1+EPS)*a_c; % already nondim

% number of space modes
N_x=config_vec(17);
N_y=config_vec(18);

% time steps per period
time_steps_per_period=200;
% how many multpiles of the period of forcing to go
time_step_multiple=400; % set to 1 to represent nonstop

% set up pattern domain
x_st=0;
x_l=2*2*pi/k_0; % corresponds to n=1 mode
x_en=x_st+x_l;
% set up nondim spatial domain
y_st=0;
y_l=2*2*pi/sqrt(3)/k_0; % corresponds to n=1 mode
y_en=y_st+y_l;

% sample points in nondim space
x_i=linspace(x_st,x_en-x_l/N_x,N_x);
y_i=linspace(y_st,y_en-y_l/N_y,N_y)';

% set up interp domain
prop_x=2^5;% how many points of the domain should represent one pattern domain?
prop_y=2^5;
x_int=linspace(x_st,x_en-x_l/prop_x,prop_x);
y_int=linspace(y_st,y_en-y_l/prop_y,prop_y)';

% create localised initial conditions
[X_i,Y_i]=meshgrid(x_i,y_i);
[X_int,Y_int]=meshgrid(x_int,y_int);
mid_A=interp2(X_i,Y_i,load('./CONT_h.txt'),X_int,Y_int);
mid_B=interp2(X_i,Y_i,load('./CONT_phi.txt'),X_int,Y_int);

% proportion of total domain in power of 2
domain_multiple=2^4; % multiply pattern domain by this 
N_x=domain_multiple*prop_x; N_y=domain_multiple*prop_y; % full domain
% repeat pattern over the domain
A_local=repmat(mid_A,domain_multiple,domain_multiple); 
B_local=repmat(mid_B,domain_multiple,domain_multiple);

% set up nondim spatial domain
x_st=0;
x_l=domain_multiple*x_l; % corresponds to n=1 mode
x_en=x_st+x_l;
% set up nondim spatial domain
y_st=0;
y_l=domain_multiple*y_l; % corresponds to n=1 mode
y_en=y_st+y_l;

% sample points in nondim space
x_i=linspace(x_st,x_en-x_l/N_x,N_x);
y_i=linspace(y_st,y_en-y_l/N_y,N_y)';

% set up localised IC
[X,Y]=meshgrid(x_i,y_i);
damping_strength=0.1;
damping_radius=4;
damping_local=(-tanh(damping_strength.*(sqrt((X-x_l/2).^2+(Y-y_l/2).^2)-damping_radius*x_l/domain_multiple))+1)/2;
A_local=damping_local.*A_local;
B_local=damping_local.*B_local;

% determine time step
total_time_steps=time_step_multiple*time_steps_per_period; % total amount of steps
% to keep DT the same over whole time
% total time values
time_start=0; % for starting fresh
% time_start=readmatrix('time_end.txt'); % for continuing solution
time_end=time_start+time_step_multiple*2*pi; % end time

% set up periodic forcing vector for one period nondim
t_i=linspace(0,2*pi-2*pi/time_steps_per_period,time_steps_per_period);
prop_m=0.893;
prop_l=1;
sin_2_t=prop_m*m_forcing*cos(m*t_i)+prop_l*l_forcing*cos(l*t_i+psil);

% take a sample every sample_point steps
sample_point=time_steps_per_period;

% % write path for configuration
file_path1=strcat('peaks_rec',num2str(epsilon_2),'_',num2str(B),...
        '_',num2str(C),'_',num2str(N_y),'_',...
        num2str(N_x),'_',num2str(prop_m,'%1.7f'),'_',...
        num2str(ang*2/pi,'%1.2f'),'_',...
        num2str(time_steps_per_period),'_',num2str(damping_strength),'_',num2str(damping_radius));
file_path1=replace(file_path1,'.','p');
file_path1=replace(file_path1,'-','minus');

file_path2=strcat('/nobackup/scrco/BIG_FILES_',file_path1);
if not(isfolder(file_path2))
     mkdir(strcat(file_path2))
end

file_path1=strcat('/nobackup/scrco/',file_path1);
if not(isfolder(file_path1))
     mkdir(strcat(file_path1))
end

% write space domain for plotting
writematrix(x_i,strcat(file_path1,'/x_domain.txt'));
writematrix(y_i,strcat(file_path1,'/y_domain.txt'));

% use localised initial condition
%h_0=1*A_local;
%phi_0=1*B_local;
%writematrix(h_0,strcat(file_path1,'/IC_h.txt'));
%writematrix(phi_0,strcat(file_path1,'/IC_phi.txt'));

% initial conditions % currently set to sin % writen to file
% h_0=0.1*rand(length(y_i),length(x_i)); % make sure not too big
% phi_0=0.1*rand(length(y_i),length(x_i)); % make sure not too big
% writematrix(h_0,'./IC_h.txt')
% writematrix(phi_0,'./IC_phi.txt')

% read initial conditions (for DT independence etc)
%h_0=readmatrix('./IC_h.txt');
%phi_0=readmatrix('./IC_phi.txt');

% to continue solution
%clear h_0 phi_0
%h_0(:,:,1)=1*readmatrix(strcat(file_path1,'/sol_h_min1time.txt'));
%phi_0(:,:,1)=1*readmatrix(strcat(file_path1,'/sol_phi_min1time.txt'));
%h_0(:,:,2)=1*readmatrix(strcat(file_path1,'/sol_h.txt'));
%phi_0(:,:,2)=1*readmatrix(strcat(file_path1,'/sol_phi.txt'));

clear h_0 phi_0
h_0(:,:,1)=1*readmatrix(strcat(file_path1,'/CONT_h_min1.txt'));
phi_0(:,:,1)=1*readmatrix(strcat(file_path1,'/CONT_phi_min1.txt'));
h_0(:,:,2)=1*readmatrix(strcat(file_path1,'/CONT_h.txt'));
phi_0(:,:,2)=1*readmatrix(strcat(file_path1,'/CONT_phi.txt'));

% write configuration in full
str=["m",num2str(m);...
"m_forcing",num2str(m_forcing);...
"l",num2str(l);...
"l_forcing",num2str(l_forcing);...
"p",num2str(p);...
"p_forcing",num2str(p_forcing);...
"psil",num2str(psil);...
"psip",num2str(psip);...
"visc_option (1 yes, 0 no)",num2str(visc_option);...
"a_forcing",num2str(a_forcing);...
"EPS",num2str(EPS);...
"a_pos (1 subharmonic, 2 harmonic)",num2str(config_vec(19));...
"k_0",num2str(k_0);...
"epsilon_2",num2str(epsilon_2);...
"B",num2str(B);...
"C",num2str(C);...
"damping_strength",num2str(damping_strength);...
"damping_radius",num2str(damping_radius);...
"prop_x",num2str(prop_x);...
"prop_y",num2str(prop_y);...
"domain_multiple",num2str(domain_multiple);...
"domain_size",strcat(num2str(N_x)," by ",num2str(N_y))];
writematrix(str,strcat(file_path1,'/configuration.txt'))

% for first run
%[sol_h,sol_phi,T,L2]=step_in_ETD2_2d_arc(time_start,time_end,...
%    time_steps_per_period,total_time_steps,x_l,y_l,N_x,N_y,h_0,phi_0...
%    ,a_forcing,epsilon_2,B,C,sin_2_t,sample_point,x_i,y_i,...
% 	file_path1,file_path2);

% for continuing
 [sol_h,sol_phi,T,L2]=step_in_ETD2_continued_2d_arc(time_start,time_end,...
   time_steps_per_period,total_time_steps,x_l,y_l,N_x,N_y...
    ,a_forcing,epsilon_2,B,C,sin_2_t,sample_point,x_i,y_i,h_0(:,:,1)...
    ,h_0(:,:,2),phi_0(:,:,1),phi_0(:,:,2),file_path1,file_path2);

quit;
